==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/ContextVarNode.h <==
// public class soot.jimple.spark.pag.ContextVarNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2b05623bde254c3 soot_jimple_spark_pag_ContextVarNode
// @dep_class 271d8e0f2f41c14 soot_jimple_spark_pag_LocalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_LocalVarNode

#include "soot/jimple/spark/pag/LocalVarNode.h"

#ifndef _JC_soot_jimple_spark_pag_ContextVarNode_H_
#define _JC_soot_jimple_spark_pag_ContextVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_LocalVarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs	_jc_soot_jimple_spark_pag_ContextVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$refs	_jc_soot_jimple_spark_pag_ContextVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$nonrefs	_jc_soot_jimple_spark_pag_ContextVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$object	_jc_soot_jimple_spark_pag_ContextVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vmethods	_jc_soot_jimple_spark_pag_ContextVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vtable	_jc_soot_jimple_spark_pag_ContextVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vtype	_jc_soot_jimple_spark_pag_ContextVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ContextVarNode$method$_init$08fe76f3cc090d87(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_spark_pag_ContextVarNode$method$context$a8db07e7ad32150d(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ContextVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ContextVarNode$method_info$context$a8db07e7ad32150d;
extern _jc_method _jc_soot_jimple_spark_pag_ContextVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ContextVarNode$vmethods {
	struct _jc_java_lang_Object$object	*(*context$a8db07e7ad32150d)(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_ContextVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods	soot_jimple_spark_pag_LocalVarNode;
	_jc_soot_jimple_spark_pag_ContextVarNode$vmethods	soot_jimple_spark_pag_ContextVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ContextVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ContextVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs {
	struct _jc_java_lang_Object$object	*context;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ContextVarNode$refs {
    _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs	soot_jimple_spark_pag_ContextVarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ContextVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs	soot_jimple_spark_pag_ContextVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ContextVarNode$object {
	_jc_soot_jimple_spark_pag_ContextVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ContextVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ContextVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ContextVarNode$vtype _jc_soot_jimple_spark_pag_ContextVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ContextVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ContextVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ContextVarNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/ContextVarNode.h <==
// public class soot.jimple.spark.pag.ContextVarNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2b05623bde254c3 soot_jimple_spark_pag_ContextVarNode
// @dep_class 271d8e0f2f41c14 soot_jimple_spark_pag_LocalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_LocalVarNode

#include "soot/jimple/spark/pag/LocalVarNode.h"

#ifndef _JC_soot_jimple_spark_pag_ContextVarNode_H_
#define _JC_soot_jimple_spark_pag_ContextVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_LocalVarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs	_jc_soot_jimple_spark_pag_ContextVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$refs	_jc_soot_jimple_spark_pag_ContextVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$nonrefs	_jc_soot_jimple_spark_pag_ContextVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ContextVarNode$object	_jc_soot_jimple_spark_pag_ContextVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vmethods	_jc_soot_jimple_spark_pag_ContextVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vtable	_jc_soot_jimple_spark_pag_ContextVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ContextVarNode$vtype	_jc_soot_jimple_spark_pag_ContextVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ContextVarNode$method$_init$08fe76f3cc090d87(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_spark_pag_ContextVarNode$method$context$a8db07e7ad32150d(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ContextVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ContextVarNode$method_info$context$a8db07e7ad32150d;
extern _jc_method _jc_soot_jimple_spark_pag_ContextVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ContextVarNode$vmethods {
	struct _jc_java_lang_Object$object	*(*context$a8db07e7ad32150d)(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_ContextVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods	soot_jimple_spark_pag_LocalVarNode;
	_jc_soot_jimple_spark_pag_ContextVarNode$vmethods	soot_jimple_spark_pag_ContextVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ContextVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ContextVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs {
	struct _jc_java_lang_Object$object	*context;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ContextVarNode$refs {
    _jc_soot_jimple_spark_pag_ContextVarNode$sub_refs	soot_jimple_spark_pag_ContextVarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ContextVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_ContextVarNode$sub_nonrefs	soot_jimple_spark_pag_ContextVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ContextVarNode$object {
	_jc_soot_jimple_spark_pag_ContextVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ContextVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ContextVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ContextVarNode$vtype _jc_soot_jimple_spark_pag_ContextVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ContextVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ContextVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ContextVarNode_H_ */
